pub struct MerkleProof {
pub path: Vec<ProofNode>,
pub leaf_index: usize,
}Expand description
A Merkle proof containing the path from a leaf to the root.
Fields
path: Vec<ProofNode>The sequence of sibling hashes needed to reconstruct the path to root.
leaf_index: usizeThe index of the leaf node this proof corresponds.